@@ -46,7 +46,10 @@ impl Display for EmbedError {
             EmbedErrorType::AuthorNameEmpty { .. } => f.write_str("the author name is empty"),
             EmbedErrorType::AuthorNameTooLong { .. } => f.write_str("the author name is too long"),
             EmbedErrorType::ColorNotRgb { color } => {
-                f.write_fmt(format_args!("the color {} is invalid", color))
+                f.write_str("the color ")?;
+                Display::fmt(color, f)?;
+
+                f.write_str(" is invalid")
             }
             EmbedErrorType::ColorZero => {
                 f.write_str("the given color value is 0, which is not acceptable")
@@ -311,7 +314,7 @@ impl EmbedBuilder {
     /// [`FIELD_VALUE_LENGTH_LIMIT`]: Self::FIELD_VALUE_LENGTH_LIMIT
     /// [`FOOTER_TEXT_LENGTH_LIMIT`]: Self::FOOTER_TEXT_LENGTH_LIMIT
     /// [`TITLE_LENGTH_LIMIT`]: Self::TITLE_LENGTH_LIMIT
-    #[allow(clippy::clippy::too_many_lines)]
+    #[allow(clippy::too_many_lines)]
     #[must_use = "should be used as part of something like a message"]
     pub fn build(mut self) -> Result<Embed, EmbedError> {
         if self.0.fields.len() > Self::EMBED_FIELD_LIMIT {
